dumdom.devcards

clj

Devcards helpers for dumdom. dumdom.devcards/defcard is a drop-in replacement for devcards.core/defcard that supports dumdom components.

The macro and helper function were lifted from devcards, and lightly adjusted to allow for dumdom components to automatically be wrapped in React elements, allowing them to be seamlessly rendered by devcards.

Devcards helpers for dumdom. dumdom.devcards/defcard is a drop-in replacement
for devcards.core/defcard that supports dumdom components.

The macro and helper function were lifted from devcards, and lightly adjusted
to allow for dumdom components to automatically be wrapped in React elements,
allowing them to be seamlessly rendered by devcards.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries